@@ -3,7 +3,8 @@
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD license.
-# However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
+# However, when used with the GPL version of PyQt the additional terms
+# described in the PyQt GPL exception also apply
 
 #
 # Author: Riverbank Computing Limited
@@ -12,20 +13,21 @@
 """ Trait definition for a PyQt-based color.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 from pyface.qt import QtGui
 
 from traits.api \
     import Trait, TraitError
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Convert a number into a QColor object:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-def convert_to_color ( object, name, value ):
+
+def convert_to_color(object, name, value):
     """ Converts a number into a QColor object.
     """
     # Try the toolkit agnostic format.
@@ -64,9 +66,9 @@ convert_to_color.info = ('a string of the form (r,g,b) or (r,g,b,a) where r, '
                          'is of the form 0xRRGGBB, a string of the form #RGB, '
                          '#RRGGBB, #RRRGGGBBB or #RRRRGGGGBBBB')
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Standard colors:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Note that this is slightly different from the wx implementation in that the
 # names do not include spaces and the full set of SVG color keywords is
@@ -75,29 +77,32 @@ standard_colors = {}
 for name in QtGui.QColor.colorNames():
     standard_colors[str(name)] = QtGui.QColor(name)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Callable that returns an instance of the PyQtToolkitEditorFactory for color
 #  editors.
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 ### FIXME: We have declared the 'editor' to be a function instead of  the
 # traitsui.qt4.color_editor.ToolkitEditorFactory class, since the
 # latter is leading to too many circular imports. In the future, try to see if
 # there is a better way to do this.
+
+
 def get_color_editor(*args, **traits):
     from traitsui.qt4.color_editor import ToolkitEditorFactory
     return ToolkitEditorFactory(*args, **traits)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Define PyQt specific color traits:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-def PyQtColor ( default = 'white', allow_none = False, **metadata ):
+
+def PyQtColor(default='white', allow_none=False, **metadata):
     """ Defines PyQt-specific color traits.
     """
     if allow_none:
-        return Trait( default, None, standard_colors, convert_to_color,
-                      editor = get_color_editor, **metadata )
+        return Trait(default, None, standard_colors, convert_to_color,
+                     editor=get_color_editor, **metadata)
 
-    return Trait( default, standard_colors, convert_to_color,
-                  editor = get_color_editor, **metadata )
+    return Trait(default, standard_colors, convert_to_color,
+                 editor=get_color_editor, **metadata)
